@@ -1,6 +1,6 @@
 /*
     ac.c - aircraft trace
-    Copyright (C) 2013-2021 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2013-2022 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -109,6 +109,7 @@ void free_acs(struct acs *acs){
     }
     if (acs->http_timer) zselect_timer_kill(zsel, acs->http_timer);
     zhttp_free(acs->http);
+    g_free(acs->url);
     g_free(acs->infolocqso.locator);
     zg_ptr_array_free_all(acs->sh.acs);
     free_acs_infos(acs);
@@ -1060,7 +1061,7 @@ void ac_format(struct qrv_item *qi, char *acstart, char *acint, int flags){
 void init_acs_infos(struct acs *acs){
     char *token_ptr = NULL;
     char *ic, *wingspan;
-    char *buf = g_strdup(txt_aircrafts);
+    char *buf = g_strdup(txt_aircraft);
     char *buf2 = buf;
 
     acs->infos = g_ptr_array_new();
