@@ -37,11 +37,14 @@ struct ac_result{
 #define ACZO_CROSSING 2
 #define ACZO_CURSOR 3
 
+#define AC_ID_MAXLEN 7
 #define AC_ICAO_MAXLEN 5
 
+
 struct ac{
+	char id[AC_ID_MAXLEN]; // ICAO 24-bit address
 	double w, h;
-	double qtf; // radians
+	double qtfdir; // radians
     int asl; // meters
     int speed; // km/h
 	time_t when; 
@@ -49,6 +52,7 @@ struct ac{
     // state
     double kx, ky; // actual position
 	double pakx, paky; // predicted path after 10 minutes
+	double qtf; // from me
 
 	struct ac_result tmpres, infores, qrvres; 
 	int zorder;
@@ -66,6 +70,9 @@ struct acs_shared{
 
     double infoctpqrb, infoctpqtf;
     int new_infoctp;
+
+	char tracked[AC_ID_MAXLEN];
+	int rotnr;
 };
 
 struct acs_thread{
@@ -137,7 +144,7 @@ void acs_http_timer(void *arg);
 void acs_goturl(struct zhttp *http);
 void acs_downloaded_callback(struct zhttp *http);
 gpointer acs_thread(gpointer arg);
-void acs_update_qth(struct acs *acs, struct subwin *sw);
+void acs_update_qth(struct acs *acs);
 void ac_update_tmpctp(char *wwl);
 void ac_update_infoctp(char *wwl);
 void ac_format(struct qrv_item *qi, char *acstart, char *acint, int flags);
@@ -145,5 +152,7 @@ void ac_format(struct qrv_item *qi, char *acstart, char *acint, int flags);
 void init_acs_infos(struct acs *acs);
 void free_acs_infos(struct acs *acs);
 int acs_get_wingspan(struct acs *acs, char *icao);
+struct ac *ac_under(struct acs *acs, struct subwin *sw);
+void ac_track(struct acs *acs, char *id, int rotnr);
 
 #endif
