@@ -986,6 +986,29 @@ int check_qrg(struct dialog_data *dlg, struct dialog_item_data *di)
     return 0;
 }
 
+/*int check_spowe(struct dialog_data *dlg, struct dialog_item_data *di)
+{
+	if (strlen(di->cdata) == 0) return 0;
+
+	char *c;
+	for (c = di->cdata; *c != '\0'; c++){
+		if (*c >= '0' && *c <= '9') continue;
+		if (*c == '.') continue;
+		if (*c == ' ') continue;
+		msg_box(NULL, VTEXT(T_BAD_NUMBER), AL_CENTER, TRANSLATE("Must be TX power in Watts without unit."), NULL, 1, VTEXT(T_CANCEL), NULL, B_ENTER | B_ESC);
+		return 1;
+	}
+
+	double d = atof(di->cdata);
+	if (!*di->cdata) {
+		msg_box(NULL, VTEXT(T_BAD_NUMBER), AL_CENTER, VTEXT(T_NUMBER_EXPECTED), NULL, 1, VTEXT(T_CANCEL), NULL, B_ENTER | B_ESC);
+		return 1;
+	}
+
+	return 0;
+}	*/
+
+
 int check_nonempty(struct dialog_data *dlg, struct dialog_item_data *di)
 {
     char *p;
@@ -2002,6 +2025,7 @@ int do_tab_compl(struct dialog_item_data *di, int tabi){
 x:;
     g_free(path);
     g_free(file);
-    free_namelist();
+    //free_namelist();
+    z_free_namelist(&namelist, &n);
     return 0;
 }
