@@ -15,6 +15,7 @@
 #include "control.h"
 #include "cwdaemon.h"
 #include "davac4.h"
+#include "dsp.h"
 #include "edi.h"
 #include "fifo.h"
 #include "inpout.h"
@@ -162,6 +163,13 @@ struct cwdaemon *init_cwdaemon(void){
             cwda->dtune   = winkey_tune;
             cwda->back    = winkey_back;
             break;
+		case CWD_HAMLIB:
+#ifdef HAVE_HAMLIB
+			cwda->text    = cwd_hamlib_text;
+			cwda->reset   = cwd_hamlib_reset;
+#else
+			log_addf("No support for hamlib");
+#endif
 /*        case CWD_WINKEY4:
             cwda->init    = winkey4_init;
             cwda->free    = winkey4_free;
@@ -675,7 +683,11 @@ void cwdaemon_abort(struct cwdaemon *cwda){
     cwda->tune = 0;
     z_pipe_write(cwda->pipe_write, "\x03", 1);
 
-#ifdef HAVE_HAMLIB
+#if defined(HAVE_SNDFILE) && defined(HAVE_HAMLIB)
+	if (gssbd->dsp->type == DSPT_HAMLIB){
+		trigs_send_voice_mem(gtrigs, 0);
+	}
+
 	trigs_set_ptt(gtrigs, 0);
 #endif
 	//dbg("cwdaemon_abort returned\n");
@@ -1096,7 +1108,19 @@ int cq_run_ssb(struct cq *cq){
     cq->mode=MOD_SSB_SSB;
     cwdaemon_ptt(cwda, 1, 0);
     cwdaemon_ssbway(cwda, 1); /* soundcard */
-    
+
+#ifdef HAVE_HAMLIB
+	if (gssbd->dsp->type == DSPT_HAMLIB){
+		trigs_send_voice_mem(gtrigs, cq->nr + 1);
+		if (cq->ssb_repeat){
+			gses->last_cq = cq;
+			gses->last_cq_timer_id = zselect_timer_new(zsel, cq->ssb_ts * 100, cq_timer_ssb2, cq);
+		}
+		redraw_later();
+		return ret;
+	}
+#endif
+
 #ifdef Z_ANDROID
     char *filename = convert_esc(cq->ssb_file, NULL, CE_NONE, time(NULL));
     if (!filename) return -1;
@@ -1197,7 +1221,8 @@ int cq_abort(int abort_rec){
     redraw_later();
     if (!abort_rec && ssbd_recording(gssbd)) return 0;
 
-    ssbd_abort(gssbd,abort_rec);
+
+	ssbd_abort(gssbd,abort_rec);
     return 0;
 }
 
@@ -1571,3 +1596,18 @@ void ac_cq(void){
     do_menu_selected(mi, NULL, ac_cq_i1);
     
 }
+
+
+#ifdef HAVE_HAMLIB
+
+int cwd_hamlib_text(struct cwdaemon *cwda, char *text){
+	trigs_send_morse(gtrigs, text);
+	return 0;
+}
+
+int cwd_hamlib_reset(struct cwdaemon *cwda){
+	trigs_stop_morse(gtrigs);
+	return 0;
+}
+
+#endif
