@@ -17,7 +17,7 @@
 
 struct cq;
 
-enum cwtype { CWD_NONE, CWD_PARPORT, CWD_TTYS, CWD_DAVAC4, CWD_CWD, CWD_WINKEY, CWD_WINKEY4x, CWD_WINKEYTCP, CWD_TTYS_SINGLE};
+enum cwtype { CWD_NONE, CWD_PARPORT, CWD_TTYS, CWD_DAVAC4, CWD_CWD, CWD_WINKEY, CWD_WINKEY4x, CWD_WINKEYTCP, CWD_TTYS_SINGLE, CWD_HAMLIB};
 
 struct cwdaemon {
 	int (*init)    (struct cwdaemon *);
@@ -135,12 +135,14 @@ struct cq{
 
     gchar *cw_str;
     int    cw_speed;  /* 0 = unused */
-    int    cw_repeat; /* 0 or 1 */
+	int    cw_repeat; /* 0 or 1 */
+	int    cw_breakable; /* 0 or 1 */
     int    cw_ts;     /* tenth of second */
     int    cw_allowifundef;
     
     gchar *ssb_file;
-    int    ssb_repeat;/* 0 or 1 */
+	int    ssb_repeat;/* 0 or 1 */
+	int    ssb_breakable;/* 0 or 1 */
     int    ssb_ts;    /* tenth of second */
 
     int stripcall;
@@ -171,6 +173,9 @@ int cq_remains_brk(void);
 void cq_timer_brk(void *arg);
 void ac_cq(void);
 
+int cwd_hamlib_text(struct cwdaemon *cwda, char *text);
+int cwd_hamlib_reset(struct cwdaemon *cwda);
+
 
 
 #endif
