@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -58,7 +58,7 @@ static gboolean free_cw_item(gpointer key, gpointer value, gpointer user_data){
     if (cwi->wwl0) g_free(cwi->wwl0);
     if (cwi->wwl1) g_free(cwi->wwl1);
     g_free(value);
-    return 0;    
+    return TRUE;    
 }
 
 static gboolean free_wc_item(gpointer key, gpointer value, gpointer user_data){
@@ -69,7 +69,7 @@ static gboolean free_wc_item(gpointer key, gpointer value, gpointer user_data){
     if (wci->call0) g_free(wci->call0);
     if (wci->call1) g_free(wci->call1);
     g_free(value);
-    return 0;
+    return TRUE;
         
 }
 
