@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -59,11 +59,10 @@ static gboolean free_dw_item(gpointer key, gpointer value, gpointer user_data){
     if (dwi->continent) g_free(dwi->continent);
     if (dwi->dxcname) g_free(dwi->dxcname);
 
-    g_hash_table_foreach_remove(dwi->wwls, free_gpointer_item, NULL);
     g_hash_table_destroy(dwi->wwls);
     
     g_free(value);
-    return FALSE;
+    return TRUE;
 }
 
 static gboolean free_wd_item(gpointer key, gpointer value, gpointer user_data){
@@ -74,7 +73,7 @@ static gboolean free_wd_item(gpointer key, gpointer value, gpointer user_data){
     if (wdi->dxc0) g_free(wdi->dxc0);
     if (wdi->dxc1) g_free(wdi->dxc1);
     g_free(value);
-    return FALSE;
+    return TRUE;
 }
 
 
@@ -132,7 +131,7 @@ struct dw_item *add_dxc(struct dw *dw, gchar *dxc, gchar *wwl0, gchar *wwl1, int
     if (!dxci) {
        dxci = g_new0(struct dw_item, 1); 
        
-       dxci->wwls = g_hash_table_new(g_str_hash, g_str_equal);
+       dxci->wwls = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
        g_hash_table_insert(dw->dw, g_strdup(dxc), dxci);
     }
     
@@ -143,15 +142,15 @@ struct dw_item *add_dxc(struct dw *dw, gchar *dxc, gchar *wwl0, gchar *wwl1, int
     dxci->wwl1 = g_strdup(wwl1);
     if (waz) dxci->waz = waz;
     if (itu) dxci->itu = itu;
-    if (continent) dxci->continent = g_strdup(continent);
-    if (dxcname) dxci->dxcname = g_strdup(dxcname);
+    if (continent && !dxci->continent) dxci->continent = g_strdup(continent);
+    if (dxcname && !dxci->dxcname) dxci->dxcname = g_strdup(dxcname);
 	if (longitude < 400) dxci->longitude = longitude;
 	if (latitude < 400) dxci->latitude = latitude;
     
     return dxci;
 }
 
-void add_dw(struct dw_item *dxci, gchar *dxc, gchar *wwl){
+void add_dw(struct dw_item *dwi, gchar *dxc, gchar *wwl){
     gpointer orig_wwl, orig_dxc;
     char wwl1[6];
 
@@ -159,16 +158,14 @@ void add_dw(struct dw_item *dxci, gchar *dxc, gchar *wwl){
     
     
     
-    if (g_hash_table_lookup_extended(dxci->wwls, (gpointer) wwl,
+    if (g_hash_table_lookup_extended(dwi->wwls, (gpointer) wwl,
                &orig_wwl, &orig_dxc)){
         
-        g_hash_table_remove(dxci->wwls, orig_wwl);
-        g_free(orig_wwl);
-        g_free(orig_dxc);
+        g_hash_table_remove(dwi->wwls, orig_wwl);
     } 
     safe_strncpy(wwl1, wwl, 5);
     /*dbg("add_dw(dxc='%s', wwl='%s')\n", dxc, wwl1);*/
-    g_hash_table_insert(dxci->wwls, g_strdup(wwl1), g_strdup(dxc) );
+    g_hash_table_insert(dwi->wwls, g_strdup(wwl1), g_strdup(dxc) );
     
 }
 
