@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -481,16 +481,29 @@ int save_all_bands_txt(int autosave){
             if (!dir) continue;
             z_mkdir_p(dir, 0775);
 
-            if (autosave == 1 && !band->dirty_save) continue;
+            if (autosave == 1 && !band->dirty_save) {
+                g_free(dir);
+                continue;
+            }
             
             if (j==0){
-                if (autosave && autosave!=1) continue;
+                if (autosave && autosave!=1) {
+                    g_free(dir);
+                    continue;
+                }
             }else{ /* floppy */
-                if (autosave && autosave!=2) continue;
-				if (nm_showed) continue;
+                if (autosave && autosave!=2) {
+                    g_free(dir);
+                    continue;
+                }
+				if (nm_showed) {
+                    g_free(dir);
+                    continue;
+                }
                 if (!floppy_mounted && !nm_showed) {
                     log_addf(VTEXT(T_NOT_MOUNTED_S), cfg->as_floppy_path);
                     nm_showed=1;
+                    g_free(dir);
 					continue;
                 }
             }
@@ -566,7 +579,10 @@ int save_all_bands_txt(int autosave){
       
         
         if (j==1){ /* floppy */
-		  	if (nm_showed) continue;
+		  	if (nm_showed) {
+                g_free(dir);
+                continue;
+            }
             filename = g_strdup_printf("%s/desc",dir);
 			z_wokna(filename);
             save_desc_to_file(filename);
@@ -684,6 +700,8 @@ static gchar *load_edi_remarks_until(FILE *f, gchar *until){
     return ret;
 }
 
+
+
 static GPtrArray *load_edi_qsos_until(FILE *f, gchar *until){
     GString *gs;
     GPtrArray *array;
@@ -693,7 +711,7 @@ static GPtrArray *load_edi_qsos_until(FILE *f, gchar *until){
     
     gs=g_string_new("");
     
-    array=g_ptr_array_new();
+	array = g_ptr_array_new();
  
     while( (c = zfile_fgets(gs, f, 0)) != NULL){
 /*        dbg("load_edi_qsos_unti: '%s'\n", c);*/
@@ -776,7 +794,7 @@ static void add_qsos_from_mem(struct band *b, GHashTable *hash, GPtrArray *qsos,
         q->exc      = g_strdup(items[8]);
         q->locator  = g_strdup(items[9]);
         
-        g_strfreev(items);
+		g_strfreev(items);
 
         c = g_strdup_printf("qso%d", i);
         add = (char *)g_hash_table_lookup(hash, c);
@@ -849,6 +867,7 @@ static void add_qsos_from_mem(struct band *b, GHashTable *hash, GPtrArray *qsos,
         
 x:;
     }
+    g_ptr_array_free(qsos, TRUE);
     recalc_allb_stats();
     minute_stats(b);
 /*    g_hash_table_foreach(ctest->bystamp, foreach_source_print, NULL);*/
@@ -1085,6 +1104,7 @@ destroy:;
 
         if (find_band_by_pband(pband)){
             log_addf(VTEXT(T_BAND_EXIST_SS), pband, file);
+            g_ptr_array_free(qsos, TRUE);
             goto destroy;
         }
 
@@ -1103,6 +1123,7 @@ destroy:;
         b = init_band(NULL, hash, NULL, NULL);
         if (!b) {
           /*  dbg("load_contest_edi: b=NULL!\n");*/
+            g_ptr_array_free(qsos, TRUE);
             goto destroy;
             
         }
@@ -1334,10 +1355,10 @@ void import_edi(void *xxx, char *filename){
     add_qsos_from_mem(band, hash, qsos, ctest->cdate);
 destroy:;    
     destroy_string_hash(hash);  
+    zg_ptr_array_free_all(qsos);  
     redraw_later();
 }
 
-
 void import_swap(void *xxx, char *filename){
 	FILE *f;
 	f = fopen(filename, "rt");
