@@ -37,5 +37,9 @@ void fifo_add_lines(struct fifo *fifo, char *data);
 int fifo_contains(struct fifo *fifo, char *needle);
 char *fifo_call_under(struct fifo *fifo, int x, int y);
 void fifo_message(void *itdata, void *menudata);
+void fifo_kst_info(void *itdata, void *menudata);
+#ifdef Z_HAVE_SDL
+void fifo_kst_ac_info(void *itdata, void *menudata);
+#endif
 
 #endif
