@@ -25,6 +25,8 @@
 #define HTML_QSO_STR(item) zg_string_eprintfa("h", gs, "<td>%s </td> ", item);
 #define HTML_QSO_STR_R(item) zg_string_eprintfa("h", gs, "<td align=\"right\">%s </td> ", item);
 #define HTML_QSO_INT(item) g_string_append_printf(gs, "<td align=\"right\">%d </td> ", item);
+#define HTML_QSO_CALL_LINK(item) zg_string_eprintfa("h", gs, "<td><a target=\"_blank\" href=\"https://www.qrz.com/db/%s\">%s </a></td> ", item, item);
+#define HTML_QSO_GRID_LINK(item) zg_string_eprintfa("h", gs, "<td><a target=\"_blank\" href=\"https://www.k7fry.com/grid/?qth=%s&from=%s&t=n\">%s </a></td> ", item, ctest->pwwlo, item);
 
 #define HTML_HDR(item) g_string_append_printf(gs, "<th bgcolor=\"#e4b97c\"><font color=\"#800000\">%s</font></th>\n", item);
 
@@ -235,8 +237,10 @@ void html_band_header(GString *gs, struct band *b, struct config_band *confb, in
 	HTML_HDR("CALLSIGN");
 	HTML_HDR("RSTS");
 	HTML_HDR("STX");
+	HTML_HDR("STX STRING");
 	HTML_HDR("RSTR");
 	HTML_HDR("SRX");
+	HTML_HDR("SRX STRING");
 	HTML_HDR("LOCATOR");
 	HTML_HDR("QRB");
 	HTML_HDR("OPERATOR");
@@ -307,15 +311,25 @@ void html_qsos(GString *gs, struct band *b, struct config_band *confb){
 		HTML_QSO_STR(q->date_str);
 		HTML_QSO_STR(html_modes[abs(q->mode)%10]);
 		HTML_QSO_STR(time);
-		HTML_QSO_STR(q->callsign);
+		if (cfg->httpd_show_links) {
+		   HTML_QSO_CALL_LINK(q->callsign);
+		} else {
+		   HTML_QSO_STR(q->callsign);
+		}
 
 		HTML_QSO_STR_R(q->rsts);
 		HTML_QSO_STR_R(q->qsonrs);
+		HTML_QSO_STR(ctest->pexch);
         
 		HTML_QSO_STR_R(q->rstr);
 		HTML_QSO_STR_R(q->qsonrr);
+		HTML_QSO_STR(q->exc);
         
-		HTML_QSO_STR(q->locator);
+		if (cfg->httpd_show_links) {
+		   HTML_QSO_GRID_LINK(q->locator);
+		} else {
+		   HTML_QSO_STR(q->locator);
+		}
 		HTML_QSO_INT((int)q->qrb);
 		HTML_QSO_STR(q->operator_);
 		HTML_QSO_STR(q->remark);
