@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2006  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -115,7 +115,7 @@ int inputln_func(struct inputln *il, struct event *ev){
             memset(il->cdata,0,il->dlen);
             il->cpos = strlen(il->cdata);
             il->term = term;
-            il->history = g_ptr_array_new();
+            if (!il->history) il->history = g_ptr_array_new();
             il->hist_i = -1;
             il_readonly(il, il->readonly);
             draw_inputln(il,1);/*FIXME*/
