@@ -103,6 +103,7 @@ struct default_kb {
 /*  !!!! CTRL needs uppercase, ALT lowercase */
 
 static struct default_kb default_main_keymap[] = {
+	{ ACT_AC_INFO, 'a', KBD_ALT },
     { ACT_BACKSPACE, KBD_BS, 0 },
     { ACT_BACKSPACE, KBD_BS, KBD_SHIFT },
     { ACT_CALLINFO, 'i', KBD_ALT },
@@ -121,7 +122,8 @@ static struct default_kb default_main_keymap[] = {
     { ACT_CQ_4, KBD_F11, 0 },
     { ACT_CQ_5, KBD_F12, 0 },
     { ACT_DELETE, KBD_DEL, 0 },
-    { ACT_DOWN, KBD_DOWN, 0 },
+	{ ACT_PAGE_DOWN, KBD_DOWN, KBD_CTRL },
+	{ ACT_DOWN, KBD_DOWN, 0 },
     { ACT_END, KBD_END, 0 },
     { ACT_ENTER, KBD_ENTER, 0 },
 	{ ACT_MAXIMIZE, KBD_F10, KBD_ALT },
@@ -164,7 +166,8 @@ static struct default_kb default_main_keymap[] = {
 	{ ACT_TOGGLE_SPLIT_VFO, '`', 0 },
     { ACT_TUNE, 't', KBD_ALT },
     { ACT_UNFINISHED, 'u', KBD_ALT },
-    { ACT_UP, KBD_UP, 0 },
+	{ ACT_PAGE_UP, KBD_UP, KBD_CTRL },
+	{ ACT_UP, KBD_UP, 0 },
     { ACT_WINDOWSHOT, KBD_F1, KBD_ALT },
     { ACT_AC_CQ, 'j', KBD_ALT },
 	{ ACT_ZOOMIN, '+', KBD_CTRL },
@@ -175,7 +178,8 @@ static struct default_kb default_main_keymap[] = {
 };
 
 static struct default_kb default_edit_keymap[] = {
-    { ACT_LEFT, KBD_LEFT, 0 },
+	{ ACT_AC_INFO, 'a', KBD_ALT },
+	{ ACT_LEFT, KBD_LEFT, 0 },
     { ACT_RIGHT, KBD_RIGHT, 0 },
     { ACT_HOME, KBD_HOME, 0 },
     { ACT_END, KBD_END, 0 },
