@@ -1,6 +1,6 @@
 /*
     kst - ON4KST chat
-    Copyright (C) 2011-2020 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2022 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -1104,7 +1104,7 @@ void sw_kst_info(void *itdata, void *menudata){
 }
 
 #ifdef Z_HAVE_SDL
-void sw_kst_ac_info(void *itdata, void *menudata){
+void sw_kst_ac_info(void *itdata /* NULL or WWL*/, void *menudata){
     struct qrv_item *qi;
     char call[40], *c;
     struct subwin *sw = (struct subwin*)menudata;
@@ -1124,7 +1124,9 @@ void sw_kst_ac_info(void *itdata, void *menudata){
     qi = qrv_get(qrv, call);
     if (qi != NULL){
         gacs->infolocqso.locator = g_strdup(qi->wwl);
-    }else{
+	}else if (itdata ) {
+		gacs->infolocqso.locator = g_strdup((char*)itdata);
+	}else{
         char *wwl = find_wwl_by_call(cw, call);
         if (wwl) {
             gacs->infolocqso.locator = g_strdup(wwl);
