@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -563,7 +563,6 @@ void settings(GString *gs){
 
 static void init(void)
 {
-	char *c = NULL;
 	char userbuf[64];
 
     parse_options(ac, av);
@@ -621,9 +620,6 @@ static void init(void)
 
     init_home();
 	
-	c = g_strdup_printf("%s/tucnak.dmp", tucnak_dir);
-	z_dump_init(c, tucnak_crash, "Tucnak-" Z_PLATFORM " " VERSION, DDIR);
-
     init_keymaps();
 	read_rc_files();
 #ifdef Z_ANDROID
@@ -636,8 +632,6 @@ static void init(void)
     	
 #ifdef Z_HAVE_SDL    
     sdl=init_sdl();
-    z_dump_init(c, tucnak_crash, "Tucnak-" Z_PLATFORM " " VERSION, DDIR); // must re-attach segv handler
-	g_free(c);
 	
     //log_addf(VTEXT(T_TUCNAK_DIRECTORY_IS), tucnak_dir);
 
@@ -822,7 +816,7 @@ static void terminate_all_subsystems(void)
     free_net(gnet);
 
     free_cwdaemon(cwda); cwda = NULL;
-    free_ssbd(gssbd); gssbd = NULL;
+    free_ssbd(gssbd, 1); gssbd = NULL;
     free_sound();
 #ifdef USE_FFT
 	free_fft(gfft);  // after ssb
@@ -838,12 +832,13 @@ static void terminate_all_subsystems(void)
     free_all_itrms();
 
     free_history_lists();
-    free_term_specs();
     free_keymaps();
     free_conv_table();
     //zselect_bh_check(zsel);
     //zselect_bh_check(zsel);
     destroy_terminal(NULL);
+	free_term_specs();
+    free_namelist();
 #ifdef Z_HAVE_SDL    
     free_sdl();
 #endif
@@ -874,7 +869,6 @@ void redraw(void){
 
 int main(int argc, char *argv[])
 {
-
 	//zavgfilter_test();
 #if 0
     GString *gs = g_string_sized_new(8000);
@@ -1139,7 +1133,6 @@ int main(int argc, char *argv[])
     
     exit(1);
 #endif  
-	//zfence_init(256, '\0', 0xee);
 #ifdef Z_MINGW
 //    MessageBox(NULL, "Hello World, I'm Tucnak compiled under mingw", "Info", MB_OK);
 
