@@ -720,6 +720,12 @@ static void dashfce(SDL_Surface *surface, int x, int y, int d) {
     z_putpixel(surface, x, y, d);
 }
 
+static int dotcnt;
+static void dotfce(SDL_Surface *surface, int x, int y, int d) {
+	if (dotcnt++ % 6 != 3) return;
+	z_putpixel(surface, x, y, d);
+}
+
 
 void plot_cor(struct subwin *sw, SDL_Surface *surface, SDL_Rect *area, int flags){
     gpointer key;
@@ -1050,7 +1056,7 @@ void plot_rotars(struct subwin *sw, SDL_Surface *surface, SDL_Rect *area, SDL_Re
     struct rotar *rot;
     int i;
     double rad,r;
-    int vx,vy,vx1,vy1,vx2,vy2;
+    int vx,vy,vx1,vy1,vx2,vy2,vxb,vyb;
     
     
     if (sw->map.w > sw->map.h)
@@ -1087,6 +1093,14 @@ void plot_rotars(struct subwin *sw, SDL_Surface *surface, SDL_Rect *area, SDL_Re
         z_line(surface, sw->ox, sw->oy, vx, vy, rot->color);
         z_triangle(surface, vx, vy, vx1, vy1, vx2, vy2, rot->color);
 
+		int kx = (ZLOC_R_EARTH * M_PI - 1) * cos(rad);
+		int ky = (ZLOC_R_EARTH * M_PI - 1) * sin(rad);
+		km2px(sw, kx, ky, &vxb, &vyb);
+		dotcnt = 0;
+		z_do_line(surface, vx, vy,
+			vxb, vyb, rot->color, dotfce);
+
+
         if (rot->beamwidth<=0) continue;
         
         rad = M_PI * (double)(rot->qtf - 90 + rot->beamwidth / 2) / 180.0;
@@ -1102,7 +1116,7 @@ void plot_rotars(struct subwin *sw, SDL_Surface *surface, SDL_Rect *area, SDL_Re
         dashcnt=0;
         z_do_line(surface, sw->ox, sw->oy,  
                 vx2, vy2, rot->color, dashfce);
-        
+
         z_do_line(surface, vx1, vy1, vx2, vy2, rot->color, dashfce);
     }
     MUTEX_UNLOCK(rotars);
