@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -185,7 +185,7 @@ static int namelistlen = 0;
 
 void contest_choose(void (*funcall)(struct menu *menu))
 {
-    int i, n, max=0;
+    int i, max=0;
     gchar *dir;
     struct menu_item *mi = NULL;
     char s[1025], *d;
@@ -197,8 +197,8 @@ void contest_choose(void (*funcall)(struct menu *menu))
 
 	dir = g_strdup(logs_dir);
 
-    n = z_scandir(dir, &namelist, select_dir_func, compare_dir_func);
-    if (n<=0){
+    namelistlen = z_scandir(dir, &namelist, select_dir_func, compare_dir_func);
+    if (namelistlen<=0){
 		progress(NULL);
 	    set_window_ptr(gses->win, (term->x-6-11)/2,(term->y-2)/2);
         do_menu(no_contests, NULL);
@@ -206,7 +206,7 @@ void contest_choose(void (*funcall)(struct menu *menu))
     }
 
     if (!(mi = new_menu(3))) return;
-    for (i=0; i<n; i++){
+    for (i=0; i<namelistlen; i++){
         FILE *f;
         gchar *c;
         int locked;
@@ -274,7 +274,7 @@ void contest_choose(void (*funcall)(struct menu *menu))
 }
 
 void free_namelist(){
-	z_free_namelist(namelist, namelistlen);
+	z_free_namelist(&namelist, &namelistlen);
 }
 
 void menu_contest_open(void *arg){
@@ -1316,11 +1316,15 @@ void do_edit_menu(void *arg)
 /************************** SETUP MENU ************************************/
 
 void menu_save_rc(void *arg){
-    gchar *filename;
-    gchar *c;
-    int ret;
+	gchar *filename;
+	gchar *c;
+	int ret;
+
+	if (opt_tucnakrc)
+		filename = g_strdup(opt_tucnakrc);
+	else
+		filename = g_strconcat(tucnak_dir, "/tucnakrc", NULL);
 
-    filename = g_strconcat(tucnak_dir, "/tucnakrc", NULL);
 	z_wokna(filename);
     ret=save_rc_file(filename);
     if (ret) {
