@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -114,7 +114,7 @@ int dlg_mark_as_error(struct dialog_data *dlg, struct dialog_item_data *di){
     qso_mark_as_error(aband, atoi(qso->qsonrs)-1);
     recalc_stats(aband);
     
-    aband->dupe_in_tmpqso_index = -1;
+	aband->dupe_qso = NULL;
     ADD_TMPQSO_STRING(aband, callsign, qso->callsign, 1, ucallsign);
     wkd_tmpqso(aband, WT_CALLSIGN, qso->callsign);
 
@@ -124,7 +124,7 @@ int dlg_mark_as_error(struct dialog_data *dlg, struct dialog_item_data *di){
 int dlg_store_as_dupe(struct dialog_data *dlg, struct dialog_item_data *di){
     struct qso *qso;             
    
-    aband->dupe_in_tmpqso_index = -1;
+	aband->dupe_qso = NULL;
     
     qso = (struct qso*) dlg->dlg->refresh_data;
 
