@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -965,7 +965,7 @@ void refresh_ssbd(void *xxx){
     STORE_STR(cfg, ssbd_hostname);
     STORE_SINT(cfg, ssbd_udp_port);
 
-    free_ssbd(gssbd);
+    free_ssbd(gssbd, 0);
     sw_scope_clear_scopes();
     gssbd=init_ssbd();
 	progress(NULL);
