@@ -792,7 +792,7 @@ void menu_rig_opts(void *arg)
         strcpy(rig_civaddr_str, "0x58");   
         strcpy(rig_ssbcw_shift_str, "0");
         strcpy(rig_lo_str, "0");        
-        strcpy(rig_poll_ms_str, "10");   
+        strcpy(rig_poll_ms_str, "300");   
         rig_qrg_r2t = 1;
         rig_qrg_t2r = 1;        
         rig_mode_t2r = 1;       
@@ -924,7 +924,7 @@ void menu_rig_opts(void *arg)
     d->items[i].data = rig_poll_ms_str;
     d->items[i].maxl = 6;
     d->items[i].fn   = check_number;
-    d->items[i].gid  = 0;
+    d->items[i].gid  = 100;
     d->items[i].gnum = 9999;
     d->items[i].msg  = CTEXT(T_RIG_POLL_MS);
     d->items[i].wrap = 1;
@@ -1099,6 +1099,7 @@ char rot_serial[EQSO_LEN];
 char rot_timeout_ms_str[EQSO_LEN];
 char rot_poll_ms_str[EQSO_LEN];
 char rot_beamwidth_str[EQSO_LEN];
+char rot_offset_str[EQSO_LEN];
 char rot_saddr_str[EQSO_LEN], rot_model_str[EQSO_LEN], rot_speed_str[EQSO_LEN];
 char rot_rem_rotstr[EQSO_LEN];
 
@@ -1121,7 +1122,8 @@ void refresh_rotar_opts(void *xxx){
     STORE_STR (crot, rot_serial);
     STORE_SINT(crot, rot_timeout_ms);
     STORE_SINT(crot, rot_poll_ms);
-    STORE_SINT(crot, rot_beamwidth);
+	STORE_SINT(crot, rot_beamwidth);
+	STORE_SINT(crot, rot_offset);
 	STORE_SINT(crot, rot_model);
 	STORE_SINT(crot, rot_speed);
     STORE_SINT(crot, rot_saddr);
@@ -1156,7 +1158,8 @@ void menu_rotar_opts(void *arg){
         strcpy(rot_serial, "");
         strcpy(rot_timeout_ms_str,"400");
         strcpy(rot_poll_ms_str,"500");
-        strcpy(rot_beamwidth_str, "20");
+		strcpy(rot_beamwidth_str, "20");
+		strcpy(rot_offset_str, "0");
         strcpy(rot_saddr_str, "240");
 		strcpy(rot_model_str, "0");
 		strcpy(rot_speed_str, "0");
@@ -1175,7 +1178,8 @@ void menu_rotar_opts(void *arg){
         LOAD_SINT (crot, rot_timeout_ms);
         LOAD_SINT (crot, rot_poll_ms);
         LOAD_SINT (crot, rot_beamwidth);
-        LOAD_SINT (crot, rot_saddr);
+		LOAD_SINT (crot, rot_offset);
+		LOAD_SINT (crot, rot_saddr);
 		LOAD_SINT (crot, rot_model);
 		LOAD_SINT (crot, rot_speed);
         LOAD_STR  (crot, rot_rem_rotstr); 
@@ -1307,9 +1311,18 @@ void menu_rotar_opts(void *arg){
     d->items[i].gnum = 360;
     d->items[i].maxl = 5;
     d->items[i].msg = CTEXT(T_BEAMWIDTH);
-    d->items[i].wrap = 1;
 
-    
+	d->items[++i].type = D_FIELD;
+	d->items[i].dlen = EQSO_LEN;
+	d->items[i].data = rot_offset_str;
+	d->items[i].fn = check_number;
+	d->items[i].gid = 0;
+	d->items[i].gnum = 359;
+	d->items[i].maxl = 5;
+	d->items[i].msg = TRANSLATE("Azimuth offset: "); //CTEXT(T_OFFSET);
+	d->items[i].wrap = 1;
+
+
     d->items[++i].type = D_FIELD;
     d->items[i].dlen = EQSO_LEN;
     d->items[i].data = rot_saddr_str;
