@@ -25,7 +25,7 @@
 #include "sdr.h"
 #include "tsdl.h"
 
-int httpd_enable, httpd_show_priv;
+int httpd_enable, httpd_show_priv, httpd_show_links;
 char httpd_port_str[EQSO_LEN], httpd_refresh_str[EQSO_LEN];
 
 void refresh_httpd_opts(void *arg){
@@ -33,6 +33,7 @@ void refresh_httpd_opts(void *arg){
     STORE_SINT(cfg, httpd_port);
     cfg->httpd_show_priv = httpd_show_priv;
     STORE_SINT(cfg, httpd_refresh);
+    cfg->httpd_show_links = httpd_show_links;
 
 	free_httpd(httpd);
 	httpd = init_httpd();
@@ -47,6 +48,7 @@ void menu_httpd_opts(void *arg){
     g_snprintf(httpd_port_str, EQSO_LEN, "%d", cfg->httpd_port);
     httpd_show_priv = cfg->httpd_show_priv;
     g_snprintf(httpd_refresh_str, EQSO_LEN, "%d", cfg->httpd_refresh);
+    httpd_show_links = cfg->httpd_show_links;
 
     d = (struct dialog *)g_malloc(sizeof(struct dialog) + 20 * sizeof(struct dialog_item));
     memset(d, 0, sizeof(struct dialog) + 20 * sizeof(struct dialog_item));
@@ -89,8 +91,16 @@ void menu_httpd_opts(void *arg){
     d->items[i].gid  = 0;
     d->items[i].gnum  = 999;
     d->items[i].msg  = CTEXT(T_REFRESH);//CTEXT(T_RIG_MODEL);
-    d->items[i].wrap = 2;
+    d->items[i].wrap = 1;
 
+    d->items[++i].type = D_CHECKBOX;      
+    d->items[i].gid = 0;
+    d->items[i].gnum = 1;
+    d->items[i].dlen = sizeof(int);
+    d->items[i].data = (char *)&httpd_show_links;
+    d->items[i].msg = CTEXT(T_LINKS);
+    d->items[i].wrap = 2;
+    
     d->items[++i].type = D_BUTTON;   /* 6 */
     d->items[i].gid = B_ENTER;
     d->items[i].fn = ok_dialog;
@@ -296,6 +306,8 @@ void choose_mode(void *itdata, void *menudata)
 {
     enum modes m = (enum modes)GPOINTER_TO_INT(itdata);
     set_mode(m);
+	default_rst_to_tmpqsos(aband);
+	redraw_later();
 }
 
 void menu_set_mode(void *itdata, void *menudata)
