@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -31,7 +31,7 @@ gboolean free_names_item(gpointer key, gpointer value, gpointer user_data){
     
     g_free(key);
     g_free(value);
-    return 0;    
+    return TRUE;    
 }
 
 void free_namedb(struct namedb *namedb){
