@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -60,10 +60,10 @@ int init_ctest(){
 
     ctest = g_new0(struct contest, 1);
     ctest->bands = g_ptr_array_new();
-    ctest->bystamp = g_hash_table_new(g_str_hash, g_str_equal);
+    ctest->bystamp = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, free_bystamp_value);
     ctest->allqsos = z_ptr_array_new();
     ctest->spypeers = g_ptr_array_new();
-    ctest->allb_prefs = g_hash_table_new(g_str_hash, g_str_equal);
+    ctest->allb_prefs = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
     ctest->exclen = 0;
 	ctest->phase = 1;
 
@@ -1299,12 +1299,11 @@ void invalidate_tmpqso(struct band *b, struct qso *q){
     }
 }
 
-void foreach_free_bystamp(gpointer key, gpointer value, gpointer data){
+void free_bystamp_value(gpointer value){
     ZPtrArray *ia;
 
     ia = (ZPtrArray *)value;
     z_ptr_array_free(ia, TRUE);
-    g_free(key);
 
 }
     
@@ -1368,8 +1367,8 @@ void free_ctest(){
     CONDGFREE(ctest->);
   */
 
-    g_hash_table_foreach_remove(ctest->allb_prefs, free_gpointer_item, NULL);
-    g_hash_table_foreach(ctest->bystamp, foreach_free_bystamp, NULL); 
+    g_hash_table_destroy(ctest->allb_prefs);
+    g_hash_table_destroy(ctest->bystamp);
     z_ptr_array_free(ctest->allqsos, TRUE);
     g_ptr_array_free(ctest->bands, TRUE);
     free_spypeers(ctest->spypeers);
@@ -1407,6 +1406,7 @@ void free_band(struct band *b){
 	g_hash_table_destroy(b->rawqsoshash);
     
     CONDGFREE(b->pband);
+    CONDGFREE(b->opsect);
     CONDGFREE(b->bandname);
     CONDGFREE(b->operator_);
     CONDGFREE(b->stxeq);
