@@ -1,6 +1,6 @@
 /*
     rain.c - Rainscatter map
-    Copyright (C) 2016 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2016-2022 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -1288,6 +1288,7 @@ void rain_rainviewer_process_json(struct rain_provider *provider, const char *js
 		if (s == NULL) break;
 
 		tt = (time_t)strtoll(s, NULL, 10);
+		g_free(s);
 		//dbg("%d  tt=%lld\n", i, (long long)tt);
 
 		g_snprintf(key, sizeof(key), "radar.past.%d.path", i);
@@ -1317,7 +1318,7 @@ void rain_rainviewer_process_json(struct rain_provider *provider, const char *js
 		zhttp_get(provider->http, zsel, url, rain_rainviewer_downloaded_image, provider);
 		g_free(url);
 	}
-
+    g_free(host);
 	g_free(provider->rv_oldpath);
 	provider->rv_oldpath = g_strdup(provider->rv_path);
 
