@@ -128,6 +128,7 @@ struct config {   /* depending on callsign */
     int httpd_port;
     int httpd_show_priv;
     int httpd_refresh;
+    int httpd_show_links;
 
     int ac_enable;       // aircraft is enabled
     char *ac_url;        // URL for fligtradar data
@@ -156,6 +157,7 @@ struct config {   /* depending on callsign */
 extern struct config *cfg;
 extern int opt_g, opt_i, opt_m, opt_s, opt_t, debug_keyboard, opt_x;
 extern long long tl;
+extern char *opt_tucnakrc;
 
 gint init_rc(void);
 void free_config_rig(struct config_rig *crig);
