@@ -135,6 +135,7 @@ struct rotar *init_rotar(struct config_rotar *crot, int rotchar){
 
     rot->desc=g_strdup(crot->rot_desc);
 	rot->beamwidth=crot->rot_beamwidth;
+	rot->offset = crot->rot_offset;
 	rot->color=0xffffffff;  /*replaced in rot_update_colors*/
 /*	rot->qtf=260+40*cfg->nr;*/
 //    rot->timer_id=-1;
@@ -255,17 +256,19 @@ int rot_seek(struct rotar *rot, int uhel, int elev){
 
     if (!rot) return 0;
 
+	int uo = rot_normalize(uhel - rot->offset);
+
     switch (rot->type){
         case ROT_REMOTE:
             c = g_strdup_printf("RS %s;%s;%d;%d\n", 
-                    rot->netid, rot->rem_rotstr, uhel, elev);
+                    rot->netid, rot->rem_rotstr, uo, elev);
             rel_write_all(c);
             g_free(c);
             
             break;
 #ifdef HAVE_HAMLIB            
         case ROT_HAMLIB:
-            rot->hl_azim = uhel;      
+			rot->hl_azim = uo;
 			rot->hl_elev = elev;
             break;
 #endif
@@ -273,7 +276,7 @@ int rot_seek(struct rotar *rot, int uhel, int elev){
             job = g_new0(struct sconn_job, 1);
             job->cmd = SCONN_ROT_AZIM;     
             job->sdev = rot->sdev;
-            job->azim = uhel;    
+			job->azim = uo;
 			job->elev = elev;
             sconn_job_add(rot->sdev->sconn, job);
             break;
@@ -364,7 +367,7 @@ void rotar_read_handler(int n, char **items){
     if (strcasecmp(cmd, "QTF")==0){
 		char *qtf = items[3];
 		char *elev = items[4];
-        rot->qtf=atoi(qtf);
+		rot->qtf = rot_normalize(atoi(qtf) + rot->offset);
 		rot->elev = atoi(elev);
         
         zs2 = zconcatesc(gnet->myid, rotstr, qtf, elev, NULL);
@@ -458,7 +461,7 @@ void rotar_remote_update(char *c){
 
     if (!rot) goto x;
 
-    rot->qtf = atoi(qtf);
+	rot->qtf = rot_normalize(atoi(qtf) + rot->offset);
     rot->elev = atoi(elev);
 	redraw_later();
 #ifdef Z_HAVE_SDL
@@ -719,3 +722,8 @@ int rot_beamwidth(){
 	return rot->rot_beamwidth;
 }
 
+int rot_normalize(int az){
+	az = az % 360;
+	if (az < 0) az += 360;
+	return az;
+}
