@@ -47,9 +47,11 @@ struct sdr {
     int n;
     int pal[FFT_COLORS];
     int grpal[FFT_COLORS];
+#ifdef Z_HAVE_SDL    
     SDL_Surface *screen;
     MUTEX_DEFINE(screen);
-    int screeny;    
+    int screeny; 
+#endif   
     double *amp, *nea_amp;
 	int amplen;
 #ifdef HAVE_SNDFILE
