@@ -111,7 +111,7 @@ void sota_spot_push(void)
     //    log_addf("No summit code in exchange contest configuration");
     //    return
     //}
-    strncpy(ssd->_summit, ctest->pexch, sizeof(ssd->_summit));
+    strncpy(ssd->_summit, ctest->pexch, sizeof(ssd->_summit)-1);
      
     token = strtok(ssd->_summit, "/"); //OK
     
