@@ -24,6 +24,8 @@ struct cntpts{
 };
 
 struct stats{
+	char bandchar;
+
     gint first_date, last_date; /* 20021115*/
     gint nqsos, nqsop;  /* without errors and dupes */
     gint nwwlp; 
@@ -41,8 +43,8 @@ struct stats{
     
 	int qso_per_hour, pts_per_hour, pts_per_50qso;
     char *mycontinent;
-    char *mydxcc;
-    struct qso *odx;
+	char *mydxcc;
+	struct qso *odx;
 	int oldphase;
 };
 
@@ -61,7 +63,7 @@ char *get_wwl(char *buf, char *wwl);
 void draw_one_bigdigit(int x, int y, int num);
 void draw_bigdigit(int x, int y, int num);
 
-struct stats *init_stats(void);
+struct stats *init_stats(char bandchar);
 void free_stats(struct stats *st);
 void clear_stats(struct stats *st);
 void update_stats(struct band *b, struct stats *st, struct qso *q);
