@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -490,7 +490,7 @@ void free_subwin(struct subwin *sw){
 #endif
     if (sw->il) g_free(sw->il);
 	if (sw->adns) zasyncdns_free(sw->adns);
-	if (sw->kstusers) g_hash_table_remove_all(sw->kstusers);
+	if (sw->kstusers) g_hash_table_destroy(sw->kstusers);
 	g_free(sw->acunder);
 	g_free(sw->callunder);
 	g_free(sw->refunder);
