@@ -39,7 +39,7 @@ struct config_rig{
 #include <zthread.h>
 
 enum trig_cmd { 
-    TRIG_FREQ, TRIG_MODE, TRIG_MODE_FREQ, TRIG_RESENDFREQ, TRIG_RIT, TRIG_PTT, TRIG_TOGGLE_SPLIT_VFO
+    TRIG_FREQ, TRIG_MODE, TRIG_MODE_FREQ, TRIG_RESENDFREQ, TRIG_RIT, TRIG_PTT, TRIG_TOGGLE_SPLIT_VFO, TRIG_SEND_VOICE_MEM, TRIG_SEND_MORSE, TRIG_STOP_MORSE
 };
 
 struct trig_job{
@@ -50,6 +50,9 @@ struct trig_job{
     freq_t freq;
     shortfreq_t rit;
 	ptt_t ptt;
+	int ch;
+	char *msg;
+
 };
 
 struct trig{
@@ -103,6 +106,10 @@ void trigs_set_rit_except(struct trigs *trigs, int except_rigr, double rit);
 void trigs_resend_freq(struct trigs *trigs, int rignr);
 void trigs_set_ptt(struct trigs *trigs, int ptt);
 void trigs_toggle_split_vfo(struct trigs *trigs);
+void trigs_send_voice_mem(struct trigs *trigs, int ch);
+void trigs_send_morse(struct trigs *trigs, const char *msg);
+void trigs_stop_morse(struct trigs *trigs);
+
 
 
 // trig functions
@@ -120,6 +127,9 @@ void trig_resend_freq(struct trig *trig);
 void trig_set_rit(struct trig *trig, shortfreq_t rit);
 void trig_set_ptt(struct trig *trig, ptt_t ptt);
 void trig_toggle_split_vfo(struct trig *trig);
+void trig_send_voice_mem(struct trig *trig, int ch);
+void trig_send_morse(struct trig *trig, const char *msg);
+void trig_stop_morse(struct trig *trig);
 
 int trig_save_riglist(const struct rig_caps *caps, void *data);
 int trig_compare (const void *a, const void *b);
