@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -227,6 +227,7 @@ struct tsdl *init_sdl(){
 		r.h=24;
 		SDL_BlitSurface(tucnak64, NULL, sdl->screen, &r);
         ty -= 64;
+        SDL_FreeSurface(tucnak64);
 	}
     ty -= zsdl->font_h;
     zsdl_printf(sdl->screen, sdl->screen->w / 2, ty, sdl->gr[12], 0, ZFONT_CENTERX, "Tucnak %s", VERSION);
@@ -296,6 +297,9 @@ void free_sdl(){
     if (sdl->screen) SDL_FreeSurface(sdl->screen);
     if (sdl->key) SDL_FreeSurface(sdl->key);
     if (sdl->xfer) SDL_FreeSurface(sdl->xfer);
+    if (sdl->xfer) SDL_FreeSurface(sdl->home);
+    if (sdl->xfer) SDL_FreeSurface(sdl->zoomin);
+    if (sdl->xfer) SDL_FreeSurface(sdl->zoomout);
     MUTEX_FREE(sdl->eventpipestate);
     zg_free0(sdl->title);
 
